<?php
/**
 * Call to Action Section options
 *
 * @package Theme Palace
 * @subpackage Food Restro Pro
 * @since Food Restro Pro 1.0.0
 */

// Add Call to Action section
$wp_customize->add_section( 'food_restro_pro_cta_section', array(
	'title'             => esc_html__( 'Call to Action','food-restro-pro' ),
	'description'       => esc_html__( 'Call to Action Section options.', 'food-restro-pro' ),
	'panel'             => 'food_restro_pro_front_page_panel',
) );

// Call to Action content enable control and setting
$wp_customize->add_setting( 'food_restro_pro_theme_options[cta_section_enable]', array(
	'default'			=> 	$options['cta_section_enable'],
	'sanitize_callback' => 'food_restro_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Food_Restro_Pro_Switch_Control( $wp_customize, 'food_restro_pro_theme_options[cta_section_enable]', array(
	'label'             => esc_html__( 'Call to Action Section Enable', 'food-restro-pro' ),
	'section'           => 'food_restro_pro_cta_section',
	'on_off_label' 		=> food_restro_pro_switch_options(),
) ) );

// Call to Action content type control and setting
$wp_customize->add_setting( 'food_restro_pro_theme_options[cta_content_type]', array(
	'default'          	=> $options['cta_content_type'],
	'sanitize_callback' => 'food_restro_pro_sanitize_select',
) );

$wp_customize->add_control( 'food_restro_pro_theme_options[cta_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'food-restro-pro' ),
	'section'           => 'food_restro_pro_cta_section',
	'type'				=> 'select',
	'active_callback' 	=> 'food_restro_pro_is_cta_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'food-restro-pro' ),
		'post' 		=> esc_html__( 'Post', 'food-restro-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'food-restro-pro' ),
	),
) );

// cta pages drop down chooser control and setting
$wp_customize->add_setting( 'food_restro_pro_theme_options[cta_content_page]', array(
	'sanitize_callback' => 'food_restro_pro_sanitize_page',
) );

$wp_customize->add_control( new Food_Restro_Pro_Dropdown_Chooser( $wp_customize, 'food_restro_pro_theme_options[cta_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'food-restro-pro' ),
	'section'           => 'food_restro_pro_cta_section',
	'choices'			=> food_restro_pro_page_choices(),
	'active_callback'	=> 'food_restro_pro_is_cta_section_content_page_enable',
) ) );

// cta posts drop down chooser control and setting
$wp_customize->add_setting( 'food_restro_pro_theme_options[cta_content_post]', array(
	'sanitize_callback' => 'food_restro_pro_sanitize_page',
) );

$wp_customize->add_control( new Food_Restro_Pro_Dropdown_Chooser( $wp_customize, 'food_restro_pro_theme_options[cta_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'food-restro-pro' ),
	'section'           => 'food_restro_pro_cta_section',
	'choices'			=> food_restro_pro_post_choices(),
	'active_callback'	=> 'food_restro_pro_is_cta_section_content_post_enable',
) ) );

// cta title setting and control
$wp_customize->add_setting( 'food_restro_pro_theme_options[cta_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['cta_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'food_restro_pro_theme_options[cta_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'food-restro-pro' ),
	'section'        	=> 'food_restro_pro_cta_section',
	'active_callback' 	=> 'food_restro_pro_is_cta_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'food_restro_pro_theme_options[cta_subtitle]', array(
		'selector'            => '#call-to-action .section-header p.section-subtitle',
		'settings'            => 'food_restro_pro_theme_options[cta_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'food_restro_pro_cta_subtitle_partial',
    ) );
}

// cta title setting and control
$wp_customize->add_setting( 'food_restro_pro_theme_options[cta_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['cta_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'food_restro_pro_theme_options[cta_title]', array(
	'label'           	=> esc_html__( 'Title', 'food-restro-pro' ),
	'section'        	=> 'food_restro_pro_cta_section',
	'active_callback' 	=> 'food_restro_pro_is_cta_section_content_custom_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'food_restro_pro_theme_options[cta_title]', array(
		'selector'            => '#call-to-action .section-header h2.section-title',
		'settings'            => 'food_restro_pro_theme_options[cta_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'food_restro_pro_cta_title_partial',
    ) );
}

// cta image setting and control.
$wp_customize->add_setting( 'food_restro_pro_theme_options[cta_sale_image]', array(
	'sanitize_callback' => 'food_restro_pro_sanitize_image',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'food_restro_pro_theme_options[cta_sale_image]',
		array(
		'label'       		=> esc_html__( 'Sale Image', 'food-restro-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'food-restro-pro' ), 400, 250 ),
		'section'     		=> 'food_restro_pro_cta_section',
		'active_callback'	=> 'food_restro_pro_is_cta_section_enable',
) ) );

// cta image setting and control.
$wp_customize->add_setting( 'food_restro_pro_theme_options[cta_image]', array(
	'sanitize_callback' => 'food_restro_pro_sanitize_image',
	'default'			=> $options['cta_image'],
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'food_restro_pro_theme_options[cta_image]',
		array(
		'label'       		=> esc_html__( 'Background Image', 'food-restro-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'food-restro-pro' ), 1920, 1080 ),
		'section'     		=> 'food_restro_pro_cta_section',
		'active_callback'	=> 'food_restro_pro_is_cta_section_content_custom_enable',
) ) );

// cta btn title setting and control
$wp_customize->add_setting( 'food_restro_pro_theme_options[cta_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'food_restro_pro_theme_options[cta_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'food-restro-pro' ),
	'section'        	=> 'food_restro_pro_cta_section',
	'active_callback' 	=> 'food_restro_pro_is_cta_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'food_restro_pro_theme_options[cta_btn_title]', array(
		'selector'            => '#call-to-action .wrapper .read-more a',
		'settings'            => 'food_restro_pro_theme_options[cta_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'food_restro_pro_cta_btn_title_partial',
    ) );
}

// cta btn link setting and control
$wp_customize->add_setting( 'food_restro_pro_theme_options[cta_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'food_restro_pro_theme_options[cta_btn_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'food-restro-pro' ),
	'section'        	=> 'food_restro_pro_cta_section',
	'active_callback' 	=> 'food_restro_pro_is_cta_section_content_custom_enable',
	'type'				=> 'url',
) );